import request from '@/utils/request'

// 查询定义销售推送不同类型的企业消息的次数列表
export function listQwPushCount(query) {
  return request({
    url: '/qw/qwPushCount/list',
    method: 'get',
    params: query
  })
}

// 查询定义销售推送不同类型的企业消息的次数详细
export function getQwPushCount(id) {
  return request({
    url: '/qw/qwPushCount/' + id,
    method: 'get'
  })
}

// 新增定义销售推送不同类型的企业消息的次数
export function addQwPushCount(data) {
  return request({
    url: '/qw/qwPushCount',
    method: 'post',
    data: data
  })
}

// 修改定义销售推送不同类型的企业消息的次数
export function updateQwPushCount(data) {
  return request({
    url: '/qw/qwPushCount',
    method: 'put',
    data: data
  })
}

// 删除定义销售推送不同类型的企业消息的次数
export function delQwPushCount(id) {
  return request({
    url: '/qw/qwPushCount/' + id,
    method: 'delete'
  })
}

// 导出定义销售推送不同类型的企业消息的次数
export function exportQwPushCount(query) {
  return request({
    url: '/qw/qwPushCount/export',
    method: 'get',
    params: query
  })
}
//查询对应的公司
export function getCompanyList() {
  return request({
    url: '/qw/qwPushCount/getCompanyList',
    method: 'get'
  })
}
